@extends ('layouts.main-layout')

@section('page-title', 'Bienvenidos a la tienda')

@section('content-area')
    <h1>Lista global de artículos</h1>
    <table class="table table-striped">
        <thead>
            <tr>
                <th>Artículo</th>
                <th>Descripción</th>
                <th>Color</th>
                <th class='celda-precio'>P. Compra</th>
                <th class='celda-precio'>P. Venta</th>
                <th class='celda-enlaces'>&nbsp</th>
            </tr>
        </thead>
        <tbody>
            @foreach ($articulos as $articulo)
                <tr>
                    <td>
                        <a href="{{ route('articulos.show', ['articulo'=>$articulo]) }}">
                            {{ $articulo->nombre }}
                        </a>
                    </td>
                    <td>{{ $articulo->descripcion }}</td>
                    <td>{{ $articulo->color }}</td>
                    <td class='celda-precio'>
                        @priceformat($articulo->precio_compra)
                    </td>
                    <td class='celda-precio'>
                        @priceformat($articulo->precio_venta)
                    </td>
                    <td>
                        <span class='zona-enlace-editar'>
                            <a href="{{ route('articulos.edit', ['articulo'=>$articulo]) }}">
                                <i class="material-icons">edit</i>
                            </a>
                        </span>
                        <span class='zona-enlace-borrar'>
                            <a href="" id="{{ $articulo }}" class="delete_link">
                                <i class="material-icons">delete</i>
                            </a>
                        </span>
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table>

    {{-- Modal para eliminación --}}
    <div class="modal" id="delete_modal" tabindex="-1" role="dialog">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Borrado de elemento</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    <p>Vas a eliminar el artículo <span id="zona_de_nombre"></span></p>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-primary" data-dismiss="modal">Cancelar</button>
                    <a id="btn_confirm" href="#" class="btn btn-danger">Eliminar</a>
                </div>
            </div>
        </div>
    </div>

    {{-- Formulario para eliminación --}}
    <form id="delete_form" method="post" action="{{ route('articulos.destroy', ['articulo'=>$articulo]) }}">
        @method('DELETE')
        @csrf
    </form>

    <script language="javascript">
        var articulo;
        var articulo_array;
        // Definimos el modal de eliminación
        $('.modal').modal({
            'dismissible':false,
            'show':false,
        });

        // Cuando se pulsa un icono de borrar
        $('.delete_link').on('click', function(e) {
            e.preventDefault();
            articulo = $(this).attr('id');
            articulo_array = JSON.parse(articulo);
            $('#zona_de_nombre').html(articulo_array["nombre"]);
            $('#delete_modal').modal('show');
        });

        // Confirmar el borrado
        $('#btn_confirm').on('click', function(e) {
            e.preventDefault();
            var destino = ($("#delete_form").attr('action'));
            var corte = destino.lastIndexOf('/') + 1;
            var destinoBase = destino.substr(0, corte);
            destino = destinoBase + articulo_array["id"];
            $("#delete_form").attr('action', destino);
            $("#delete_form").submit();
        });
    </script>
@endsection
