<?php

namespace App\Http\Controllers;

use App\Category;
use Illuminate\Http\Request;
use Illuminate\Pagination\LengthAwarePaginator;

class CategoryController extends Controller
{
    public function list()
    {
        $categorias = Category::orderBy('cat_name')
            ->paginate(10);
        $opciones = $categorias->getOptions();

        $totalDeCategorias = Category::count();
        $categorias = $categorias->map(function ($cat) use ($totalDeCategorias) {
            $cat->descendientes = $cat->categories;
            $cat->ascendientes = $cat->parentCategories;
            $cat->dispDesc = $totalDeCategorias - ($cat->descendientes->count() + 1);
            $cat->dispAsc = $totalDeCategorias - ($cat->ascendientes->count() + 1);
            return $cat;
        });

        $categorias = new LengthAwarePaginator($categorias, Category::count(), 10, null, $opciones);

        return view('categories.list')
            ->with([
                'categorias' => $categorias
            ]);
    }

    /** El siguiente método determina las categorías que
     * pueden ser relacionadas con la categoría actual,
     * bien sea como descendientes o ascendientes, según
     * se haya hecho la llamada.
     */
    public function CatsAttaching(Request $request)
    {
        $categoriaParaRelacionar = Category::find($request->categoria_seleccionada);
        $categorias = Category::all();
        $relacionadosActuales = ($request->asc_desc == "ASC") ? $categoriaParaRelacionar->parentCategories : $categoriaParaRelacionar->categories;
        $disponiblesParaAsociar = $categorias->filter(function($cat) use ($relacionadosActuales, $request) {
            if (!$relacionadosActuales->contains('id', $cat->id)
            && $cat->id != $request->categoria_seleccionada) {
                return $cat;
            }
        })
        ->sortBy('cat_name');

        return view('categories.asociar')
            ->with([
                'catActual' => $categoriaParaRelacionar,
                'disponibles' => $disponiblesParaAsociar,
                'sentido' => $request->asc_desc,
            ]);
    }

    public function AddAttaches(Request $request)
    {
        $cat = Category::find($request->cat_en_curso);

        if ($request->sentido == "ASC") {
            $cat->parentCategories()->syncWithoutDetaching($request->cats_para_asociar);
        } else {
            $cat->categories()->syncWithoutDetaching($request->cats_para_asociar);
        }

        return redirect()->route('listar');
    }

    public function CatsDetaching(Request $request)
    {
        $catEnCurso = Category::find($request->categoria_seleccionada);
        $catParaQuitar = Category::find($request->categoria_para_quitar);

        if ($request->asc_desc == "DESC") {
            $catEnCurso->categories()->detach($catParaQuitar);
        } else {
            $catEnCurso->parentCategories()->detach($catParaQuitar);
        }

        return redirect()->route('listar');
    }
}
