<?php

namespace App\Http\Controllers;

use App\Category;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Collection;
use Illuminate\Http\Request;

class MainController extends Controller
{
    public function index()
    {
        return view('index');
    }

    public function list($type)
    {
        $categorias = Collection::hierarchy(Category::class, 'category_name', $type, '&nbsp;', 4);

        return view('categories.list')
            ->with([
                'categorias'=>$categorias,
                'type'=>$type
            ]);
    }

    public function create()
    {
        $categoriasActuales = Collection::hierarchy(Category::class, 'category_name', 'N', '&nbsp;', 4);

        return view('categories.create')
            ->with([
                'categorias'=>$categoriasActuales
            ]);
    }

    public function store(Request $request)
    {
        $reglas = [
            'category_name' => 'required|max:255'
        ];
        if ($request->parent_id != '00') {
            $reglas['parent_id'] = 'exists:categories,id';
        }

        $mensajes = [
            'category_name.required' => 'Debes teclear el nombre de la nueva categoría.',
            'category_name.max' => 'El nombre de la nueva categoría es muy largo.',
            'parent_id.exists' => 'La categoría padre seleccionada no existe.',
        ];

        $request->validate($reglas, $mensajes);

        $request->category_name = str_replace(['<', '>'], '-', $request->category_name);
        $request->category_description = str_replace(['<', '>'], '-', $request->category_description);

        $nuevaCategoria = new Category;
        $nuevaCategoria->category_name = $request->category_name;
        $nuevaCategoria->category_description = $request->category_description;
        if ($request->parent_id != '00')
        {
            $nuevaCategoria->parent_id = $request->parent_id;
        }
        $nuevaCategoria->save();

        if ($request->parent_id == '00')
        {
            $nuevaCategoria->parent_id = $nuevaCategoria->id;
            $nuevaCategoria->save();
        }

        return view('categories.stored')
            ->with([
                'category' => $nuevaCategoria->category_name
            ]);
    }

    public function edit($id)
    {
        $todasLasCategorias = Collection::hierarchy(Category::class, 'category_name', 'N', '&nbsp;', 4);
        $actualYDependientes = Collection::hierarchy(Category::class, 'category_name', 'N', '&nbsp;', 4, $id);

        $disponibles = $todasLasCategorias->filter(function ($cat) use ($actualYDependientes) {
            if ($actualYDependientes->contains('id', $cat->id) === false)
            {
                return $cat;
            }
        });

        $idsDisponibles = $disponibles->pluck('id')->toArray();
        array_unshift($idsDisponibles, $id);
        $idsDisponibles = implode(',', $idsDisponibles);

        $categoriaEnEdicion = Category::find($id);

        return view('categories.edit')
            ->with([
                'categoriasDisponibles' => $disponibles,
                'actual' => $categoriaEnEdicion,
                'disponibles' => $idsDisponibles
            ]);
    }

    public function update(Request $request)
    {
        $reglas = [
            'category_name' => 'required|max:255',
            'parent_id' => 'required|in:'.$request->idsDisponibles
        ];

        $mensajes = [
            'category_name.required' => 'Debes teclear el nombre de la nueva categoría.',
            'category_name.max' => 'El nombre de la nueva categoría es muy largo.',
            'parent_id.required' => 'Tienes que seleccionar la categoría padre.',
            'parent_id.in' => 'La categoría padre seleccionada no está disponible.',
        ];

        $request->validate($reglas, $mensajes);

        $actualizacion = Category::find($request->id);
        $actualizacion->category_name = $request->category_name;
        $actualizacion->category_description = $request->category_description;
        $actualizacion->parent_id = $request->parent_id;
        $actualizacion->save();

        return view('categories.updated')
            ->with([
                'categoria'=>$actualizacion->category_name
            ]);
    }

    public function delete($id)
    {
        $category = Category::find($id);

        return view('categories.confirm-delete')
            ->with([
                'categoria' => $category->category_name,
                'id' => $id
            ]);
    }

    public function erase($id)
    {
        $categoriasParaEliminar = Collection::hierarchy(Category::class, 'category_name', 'N', '', 0, $id);

        $categoriasParaEliminar = $categoriasParaEliminar->map(function ($cat) {
            $cat->delete();
            return $cat;
        });

        return view('categories.deleted')
            ->with([
                'eliminadas' => $categoriasParaEliminar,
                'id' => $id
            ]);
    }
}
