<?php

namespace App\Http\Controllers;

use App\Category;
use Illuminate\Http\Request;
use Illuminate\Pagination\LengthAwarePaginator;

class CategoryController extends Controller
{
    public function list()
    {
        $categorias = Category::orderBy('cat_name')
            ->paginate(10);
        $todasLasCategorias = Category::all();
        $opciones = $categorias->getOptions();

        $categorias = $categorias->map(function ($cat) use ($todasLasCategorias) {
            $cat->descendientes = $cat->categories;
            $cat->ascendientes = $cat->parentCategories;
            $cat->dispDesc = $todasLasCategorias->filter(function ($disp) use ($cat) {
                if (!$cat->descendientes->contains('id', $disp->id)
                && $cat->id != $disp->id) {
                    return $disp;
                }
            });
            $cat->dispAsc = $todasLasCategorias->filter(function ($disp) use ($cat) {
                if (!$cat->ascendientes->contains('id', $disp->id)
                && $cat->id != $disp->id) {
                    return $disp;
                }
            });
            return $cat;
        });

        $categorias = new LengthAwarePaginator($categorias, Category::count(), 10, null, $opciones);

        return view('categories.list')
            ->with([
                'categorias' => $categorias
            ]);
    }

    /** El siguiente método determina las categorías que
     * pueden ser relacionadas con la categoría actual,
     * bien sea como descendientes o ascendientes, según
     * se haya hecho la llamada.
     */
    public function CatsAttaching(Request $request)
    {
        $categoriaParaRelacionar = Category::find($request->categoria_seleccionada);
        $categorias = Category::all();
        $relacionadosActuales = ($request->asc_desc == "ASC") ? $categoriaParaRelacionar->parentCategories : $categoriaParaRelacionar->categories;
        $disponiblesParaAsociar = $categorias->filter(function($cat) use ($relacionadosActuales, $request) {
            if (!$relacionadosActuales->contains('id', $cat->id)
            && $cat->id != $request->categoria_seleccionada) {
                return $cat;
            }
        })
        ->sortBy('cat_name');

        return view('categories.asociar')
            ->with([
                'catActual' => $categoriaParaRelacionar,
                'disponibles' => $disponiblesParaAsociar,
                'sentido' => $request->asc_desc,
            ]);
    }

    public function AddAttaches(Request $request)
    {
        $cat = Category::find($request->cat_en_curso);
        foreach ($request->cats_para_asociar as $cat_para_asociar) {
            if ($request->sentido == "ASC") {
                $cat->parentCategories()->attach($cat_para_asociar);
            } else {
                $cat->categories()->attach($cat_para_asociar);
            }
        }

        return redirect()->route('listar');
    }

    public function CatsDetaching(Request $request)
    {
        $catEnCurso = Category::find($request->categoria_seleccionada);
        $catParaQuitar = Category::find($request->categoria_para_quitar);

        if ($request->asc_desc == "DESC") {
            $catEnCurso->categories()->detach($catParaQuitar);
        } else {
            $catEnCurso->parentCategories()->detach($catParaQuitar);
        }

        return redirect()->route('listar');
    }
}
