<?php

namespace App\Http\Controllers;

use App\Articulo;
use Illuminate\Http\Request;
use Illuminate\Http\Response;

class ArticuloController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $articulos = Articulo::all();
        return view('articulos.listar-todos')
            ->with([
                'articulos'=>$articulos
            ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('articulos.nuevo');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // Verificamos que se han tecleado los campos obligatorios,
        // y no excedan la longitud máxima.
        $reglas = [
            'form_nombre' => 'required|max:50|unique:articulos,nombre',
            'form_color' => 'required|max:255',
            'form_descripcion' => 'required',
            'form_compra' => 'required|lt:form_venta',
            'form_venta' => 'required|gt:form_compra'
        ];

        $request->validate($reglas);

        // Ya se puede crear el objeto
        $nuevoArticulo = new Articulo;
        $nuevoArticulo->nombre = $request['form_nombre'];
        $nuevoArticulo->descripcion = $request['form_descripcion'];
        $nuevoArticulo->color = $request['form_color'];
        $nuevoArticulo->precio_compra = $request['form_compra'];
        $nuevoArticulo->precio_venta = $request['form_venta'];
        $nuevoArticulo->envio_domicilio = $request['form_envio'];
        $nuevoArticulo->stock = $request['form_stock'];
        $nuevoArticulo->observaciones = $request['form_observaciones'];
        // Persistimos el objeto en la base de datos
        $nuevoArticulo->save();

        // Pasamos a una vista que informa de que se ha grabado el artículo
        return view('articulos.grabado')
            ->with([
                'articulo'=>$request['form_nombre']
            ]);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Articulo  $articulo
     * @return \Illuminate\Http\Response
     */
    public function show(Articulo $articulo)
    {
        return view('articulos.mostrar-articulo')
            ->with([
                'articulo'=>$articulo
            ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Articulo  $articulo
     * @return \Illuminate\Http\Response
     */
    public function edit(Articulo $articulo)
    {
        return view('articulos.editar')
            ->with([
                'articulo' => $articulo
            ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Articulo  $articulo
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Articulo $articulo)
    {
        // Verificamos que se han tecleado los campos obligatorios,
        // y no excedan la longitud máxima.
        $reglas = [
            'nombre' => 'required|max:50|unique:articulos,nombre,'.$articulo->id.',id',
            'color' => 'required|max:255',
            'descripcion' => 'required',
            'precio_compra' => 'required|lt:precio_venta',
            'precio_venta' => 'required|gt:precio_compra'
        ];

        $request->validate($reglas);

        $cambio = Articulo::find($articulo->id);
        $cambio->nombre = $request->nombre;
        $cambio->descripcion = $request->descripcion;
        $cambio->color = $request->color;
        $cambio->precio_compra = $request->precio_compra;
        $cambio->precio_venta = $request->precio_venta;
        $cambio->envio_domicilio = $request->envio_domicilio;
        $cambio->stock = $request->stock;
        $cambio->observaciones = $request->observaciones;

        $cambio->save();

        return view('articulos.actualizado')
            ->with([
                'nombre'=>$cambio->nombre
            ]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Articulo  $articulo
     * @return \Illuminate\Http\Response
     */
    public function destroy(Articulo $articulo)
    {
        $eliminar = Articulo::find($articulo->id);
        $eliminar->delete();

        return view('articulos.eliminado')
            ->with(['nombre'=>$eliminar->nombre]);
    }
}
